pub struct ApproveCtx {
pub policy: Pubkey,
pub freeze_authority: Pubkey,
pub mint: Pubkey,
pub metadata: Pubkey,
pub mint_state: Pubkey,
pub from: Pubkey,
pub from_account: Pubkey,
pub to: Pubkey,
pub token_program: Pubkey,
pub cmt_program: Pubkey,
pub instructions: Pubkey,
}Expand description
Generated client accounts for ApproveCtx.
Fields
policy: Pubkeymint: Pubkeymetadata: Pubkeymint_state: Pubkeyfrom: Pubkeyfrom_account: Pubkeyto: Pubkeytoken_program: Pubkeycmt_program: Pubkeyinstructions: PubkeyTrait Implementations
Sourceimpl BorshSerialize for ApproveCtxwhere
Pubkey: BorshSerialize,
impl BorshSerialize for ApproveCtxwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for ApproveCtx
impl ToAccountMetas for ApproveCtx
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for ApproveCtx
impl RefUnwindSafe for ApproveCtx
impl Send for ApproveCtx
impl Sync for ApproveCtx
impl Unpin for ApproveCtx
impl UnsafeUnpin for ApproveCtx
impl UnwindSafe for ApproveCtx